pub struct RpcViewStateResponse {
pub block_hash: CryptoHash,
pub block_height: u64,
pub proof: Vec<String>,
pub values: Vec<StateItem>,
}Expand description
Resulting state values for a view state query request
JSON schema
{
"description": "Resulting state values for a view state query request",
"type": "object",
"required": [
"block_hash",
"block_height",
"values"
],
"properties": {
"block_hash": {
"$ref": "#/components/schemas/CryptoHash"
},
"block_height": {
"type": "integer",
"format": "uint64",
"minimum": 0.0
},
"proof": {
"type": "array",
"items": {
"type": "string"
}
},
"values": {
"type": "array",
"items": {
"$ref": "#/components/schemas/StateItem"
}
}
}
}Fields
block_hash: CryptoHashblock_height: u64proof: Vec<String>values: Vec<StateItem>Trait Implementations
Sourceimpl Clone for RpcViewStateResponse
impl Clone for RpcViewStateResponse
Sourcefn clone(&self) -> RpcViewStateResponse
fn clone(&self) -> RpcViewStateResponse
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for RpcViewStateResponse
impl Debug for RpcViewStateResponse
Sourceimpl<'de> Deserialize<'de> for RpcViewStateResponse
impl<'de> Deserialize<'de> for RpcViewStateResponse
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl From<&RpcViewStateResponse> for RpcViewStateResponse
impl From<&RpcViewStateResponse> for RpcViewStateResponse
Sourcefn from(value: &RpcViewStateResponse) -> Self
fn from(value: &RpcViewStateResponse) -> Self
Converts to this type from the input type.